@@ -3,6 +3,7 @@ import os
 import json
 import zipfile
 import shutil
+import time
 import win32com.shell.shell as shell
 from multiprocessing.connection import Listener
 
@@ -47,10 +48,21 @@ def product_visualization_export(
     # launch VStitcher
     se_ret = shell.ShellExecuteEx(fMask=0x140, lpFile=r"{}".format(vstitcher_launcher_file), nShow=1)
 
-    # wait for task finish
+    # wait for program load
     address = ('localhost', PROCESS_COMMUNICATION_PORT)
     listener = Listener(address, authkey=PROCESS_COMMUNICATION_PASSWORD)
     conn = listener.accept()
+    while True:
+        msg = conn.recv()
+        break
+
+    # trigger import
+    import pyautogui
+    time.sleep(0.01)
+    pyautogui.hotkey('ctrl', 'shift', 'i')
+    pyautogui.typewrite(project_file_name, interval=0.001)
+
+    # wait for task finish
     output_name = ''
     while True:
         msg = conn.recv()
